@@ -118,8 +118,8 @@ class NeptuneExperimentTracker(ExperimentTracker):
         loggable = self.project if projectLevel else self.tracker
 
         for (key, value) in valueMap.items():
-            if key in loggable:
-                del loggable[key]
+            if f"{path}/{key}" in loggable:
+                del loggable[f"{path}/{key}"]
 
             if isinstance(value, Figure):
                 fileHandle, previewHandle = BytesIO(), BytesIO()
