@@ -130,7 +130,7 @@ class RegressorCollection:
                 if kwargs != None:
                     for name, kernel in gaussianRegressor.selectedKernels.items():
                         gaussianWithKernel = gaussianRegressor.load(kernel, **kwargs)
-                        gaussianWithKernel.__class__.__name__ = (
+                        gaussianWithKernel.__name__ = (
                             f"{gaussianRegressor.__class__.__name__}Kernel{name}"
                         )
                         self.selectedRegressors.append(gaussianWithKernel)
